@@ -5,7 +5,8 @@ algorithm. pyfribidi can also convert text from visual order to
 logical order, but the conversion may be wrong in certain cases.
 """
 
-__version__ = "0.11.0"
+__version__ = "0.12.0"
+import six
 from _pyfribidi import LTR, ON, RTL, log2vis as _log2vis
 
 def log2vis(logical, base_direction=RTL, encoding="utf-8", clean=False, reordernsm=True):
@@ -25,8 +26,8 @@ def log2vis(logical, base_direction=RTL, encoding="utf-8", clean=False, reordern
     - encoding: optional string encoding (ignored for unicode input)
     """
 
-    if not isinstance(logical, unicode):
-        logical = unicode(logical, encoding)
+    if not isinstance(logical, six.text_type):
+        logical = six.text_type(logical, encoding)
     else:
         encoding = None
     res = _log2vis(logical, base_direction=base_direction, clean=clean, reordernsm=reordernsm)
